@@ -25,6 +25,7 @@
 
 enum {
   DOWNLOAD_ADDED,
+  DOWNLOAD_COMPLETED,
   DOWNLOAD_REMOVED,
 
   ESTIMATED_PROGRESS_CHANGED,
@@ -32,8 +33,7 @@ enum {
   LAST_SIGNAL
 };
 
-struct _EphyDownloadsManager
-{
+struct _EphyDownloadsManager {
   GObject parent_instance;
 
   GList *downloads;
@@ -56,7 +56,7 @@ ephy_downloads_manager_acquire_session_inhibitor (EphyDownloadsManager *manager)
   manager->inhibitor_cookie = gtk_application_inhibit (GTK_APPLICATION (ephy_embed_shell_get_default ()),
                                                        NULL,
                                                        GTK_APPLICATION_INHIBIT_LOGOUT | GTK_APPLICATION_INHIBIT_SUSPEND,
-                                                      "Downloading");
+                                                       "Downloading");
 
   if (manager->inhibitor_cookie == 0)
     g_warning ("Failed to acquire session inhibitor for active download. Is gnome-session running?");
@@ -105,6 +105,14 @@ ephy_downloads_manager_class_init (EphyDownloadsManagerClass *klass)
                   G_TYPE_NONE, 1,
                   EPHY_TYPE_DOWNLOAD);
 
+  signals[DOWNLOAD_COMPLETED] =
+    g_signal_new ("download-completed",
+                  EPHY_TYPE_DOWNLOADS_MANAGER,
+                  G_SIGNAL_RUN_LAST,
+                  0, NULL, NULL, NULL,
+                  G_TYPE_NONE, 1,
+                  EPHY_TYPE_DOWNLOAD);
+
   signals[DOWNLOAD_REMOVED] =
     g_signal_new ("download-removed",
                   EPHY_TYPE_DOWNLOADS_MANAGER,
@@ -126,6 +134,7 @@ download_completed_cb (EphyDownload         *download,
                        EphyDownloadsManager *manager)
 {
   g_signal_emit (manager, signals[ESTIMATED_PROGRESS_CHANGED], 0);
+  g_signal_emit (manager, signals[DOWNLOAD_COMPLETED], 0, download);
   ephy_downloads_manager_release_session_inhibitor (manager);
 }
 
