@@ -194,6 +194,18 @@ show_preferences (GSimpleAction *action,
   window_cmd_edit_preferences (NULL, EPHY_WINDOW (window));
 }
 
+static void
+show_shortcuts (GSimpleAction *action,
+                GVariant      *parameter,
+                gpointer       user_data)
+{
+  GtkWindow *window;
+
+  window = gtk_application_get_active_window (GTK_APPLICATION (ephy_shell));
+
+  window_cmd_help_shortcuts (NULL, GTK_WIDGET (window));
+}
+
 static void
 show_help (GSimpleAction *action,
            GVariant      *parameter,
@@ -232,6 +244,7 @@ static GActionEntry app_entries[] = {
   { "bookmarks", show_bookmarks, NULL, NULL, NULL },
   { "history", show_history, NULL, NULL, NULL },
   { "preferences", show_preferences, NULL, NULL, NULL },
+  { "shortcuts", show_shortcuts, NULL, NULL, NULL },
   { "help", show_help, NULL, NULL, NULL },
   { "about", show_about, NULL, NULL, NULL },
   { "quit", quit_application, NULL, NULL, NULL },
